       IDENTIFICATION DIVISION.
       PROGRAM-ID.    STAFMTC2.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any non-commercial purpose and without fee is hereby      *
      * granted, provided the SimoTime copyright notice appear on all *
      * copies of the software. The SimoTime name or Logo may not be  *
      * used in any advertising or publicity pertaining to the use    *
      * of the software without the written permission of SimoTime    *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      * SOURCE MODULE STAFMTC2.CBL
      *****************************************************************
      *
      * STAFMTC2 - This program receives and processes the edited and
      * formatted data string from the Callable Application Program
      * Extension member (SimoCAPE).
      *
      * CALLING PROTOCOL
      * ----------------
      *    call 'STAFMTC2' using CAPE-XCTL-API.
      *
      * The format of the LINKAGE SECTION paramter is as follows:
      *
      *    01  CAPE-XCTL-API.
      *        05  CAPE-ID             pic X(8).
      *        05  CAPE-DEBUG          pic X(8).
      *        05  CAPE-GREGORIAN-DATE pic 9(8).
      *        05  CAPE-DATE-EDITED    pic X(10).
      *        05  CAPE-DATE-VERBAGE   pic X(16).
      *        05  CAPE-JULIAN-DATE    pic 9(7).
      *        05  CAPE-LEAP-YEAR-YN   pic X.
      *        05  CAPE-DAYS-IN-MONTH  pic 99.
      *        05  CAPE-MONTH-VERBAGE  pic X(10).
      *        05  CAPE-AMOUNT         pic 9(11).
      *
      *****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1997/02/27 Simmons, Created program.
      *
      *****************************************************************
      *
       DATA DIVISION.
       WORKING-STORAGE SECTION.
      *
      *****************************************************************
      *    Data-structure for Title and Copyright...
      *****************************************************************
       01  SIM-TITLE.
           05  T1 pic X(11) value '* STAFMTC2 '.
           05  T2 pic X(34) value 'Receive Edited Date Parameters    '.
           05  T3 pic X(10) value ' v03.01.24'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* STAFMTC2 '.
           05  C2 pic X(20) value 'Copyright 1987-2019 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.

      *****************************************************************
       01  FIRST-TIME              pic X       value 'Y'.
      *****************************************************************
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* STAFMTC2 '.
           05  MESSAGE-TEXT        pic X(68).

      *****************************************************************
       LINKAGE SECTION.
       COPY PASSCAPE.
      *****************************************************************
      * Mainline processing routine...
      *****************************************************************
       PROCEDURE DIVISION using CAPE-XCTL-API.
           if  FIRST-TIME not = 'N'
               perform POST-COPYRIGHT
               move 'N' to FIRST-TIME
           end-if

           move 'Gregorian Date .............. ' to MESSAGE-TEXT
           move CAPE-GREGORIAN-DATE              to MESSAGE-TEXT(31:10)
           perform POST-MESSAGE

           move 'Edited Gregorian Date ....... ' to MESSAGE-TEXT
           move CAPE-DATE-EDITED                 to MESSAGE-TEXT(31:10)
           perform POST-MESSAGE

           move 'Text Date ................... ' to MESSAGE-TEXT
           move CAPE-DATE-VERBAGE                to MESSAGE-TEXT(31:16)
           perform POST-MESSAGE

           move 'Julian Date ................. ' to MESSAGE-TEXT
           move CAPE-JULIAN-DATE                 to MESSAGE-TEXT(31:7)
           perform POST-MESSAGE

           move 'Days Remaining in the Year .. ' to MESSAGE-TEXT
           move CAPE-DAYS-REMAINING              to MESSAGE-TEXT(31:3)
           perform POST-MESSAGE

           move 'Leap Year Flag (Y or N) ..... ' to MESSAGE-TEXT
           move CAPE-LEAP-YEAR-YN                to MESSAGE-TEXT(31:1)
           perform POST-MESSAGE

           move 'Days in the Month ........... ' to MESSAGE-TEXT
           move CAPE-DAYS-IN-MONTH               to MESSAGE-TEXT(31:2)
           perform POST-MESSAGE

           move 'Text for the Month .......... ' to MESSAGE-TEXT
           move CAPE-MONTH-VERBAGE               to MESSAGE-TEXT(31:10)
           perform POST-MESSAGE

           move 'Amount ...................... ' to MESSAGE-TEXT
           move CAPE-AMOUNT                      to MESSAGE-TEXT(31:11)
           perform POST-MESSAGE

           GOBACK.

      *****************************************************************
      * The following routines are in alphabetical order...           *
      *****************************************************************
      *
      *****************************************************************
      *    Display Copyright or Program Message...
      *    ------------------------------------------------------------
       POST-ABEND.
           if  MESSAGE-TEXT not = SPACES
               perform POST-MESSAGE
           end-if
           move 'Program is ABENDING...' to MESSAGE-TEXT
           perform POST-MESSAGE
           STOP RUN.

       POST-COPYRIGHT.
           display SIM-TITLE
           display SIM-COPYRIGHT
           exit.

       POST-MESSAGE.
           display MESSAGE-BUFFER
           move SPACES to MESSAGE-TEXT
           exit.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
